package net.wanji.opt.servicev2.report.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.ApiModelProperty;
import lombok.extern.slf4j.Slf4j;
import net.wanji.databus.dao.mapper.BaseCrossInfoMapper;
import net.wanji.databus.po.BaseCrossInfoPO;
import net.wanji.opt.common.enums.*;
import net.wanji.opt.controllerv2.report.util.TimeIntervalMerger;
import net.wanji.opt.controllerv2.report.vo.*;
import net.wanji.opt.dao.mapper.report.CrossRidLaneMapper;
import net.wanji.opt.entity.report.AnalysisReportCrossPeakDetail;
import net.wanji.opt.entity.report.CrossRidLaneDTO;
import net.wanji.opt.servicev2.report.CrossRidLaneService;
import net.wanji.opt.vo2.report.CrossRidLaneResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.stream.Collectors;

@Service
@Slf4j
public class CrossRidLaneServiceImpl implements CrossRidLaneService {

    @Autowired
    private CrossRidLaneMapper crossRidLaneMapper;
    @Autowired
    private BaseCrossInfoMapper baseCrossInfoMapper;

    @Override
    public List<CrossRidLaneResult> getCrossInfoList(String crossIds) {
        List<String> crossIdList = null;
        if (ObjectUtil.isNotEmpty(crossIds)) {
            crossIdList = Arrays.stream(crossIds.split(","))
                    .map(String::trim) // 去除可能的空格
                    .filter(s -> !s.isEmpty()) // 过滤掉空字符串
                    .collect(Collectors.toList());
        }
        List<CrossRidLaneDTO> crossRidLaneDTOList = crossRidLaneMapper.getCrossInfoList(crossIdList);
        Map<String, List<CrossRidLaneDTO>> crossIdMap = crossRidLaneDTOList.stream().collect(Collectors.groupingBy(CrossRidLaneDTO::getCrossId));
        List<CrossRidLaneResult> crossRidLaneResultList = new ArrayList<>();
        for (List<CrossRidLaneDTO> crossRidLaneDTOS : crossIdMap.values()) {
            Map<String, List<CrossRidLaneDTO>> laneNameMap = crossRidLaneDTOS.stream().collect(Collectors.groupingBy(x -> {
                if (ObjectUtil.isNotEmpty(x.getLaneName())) {
                    String[] split = x.getLaneName().split(":");
                    return split[0];
                }
                String[] strings = x.getCrossName().split("与");
                return strings[0];
            }));
            CrossRidLaneResult crossRidLaneResult = new CrossRidLaneResult();
            crossRidLaneResult.setCrossId(crossRidLaneDTOS.get(0).getCrossId());
            crossRidLaneResult.setCrossName(crossRidLaneDTOS.get(0).getCrossName());
            crossRidLaneResult.setType(CrossTypeEnum.getDesc(crossRidLaneDTOS.get(0).getType()));
            crossRidLaneResult.setLocation(getLocation(crossRidLaneDTOS.get(0).getLocation()));

            List<CrossRidLaneVO> crossRidLaneVOS = new ArrayList<>();
            for (String laneName : laneNameMap.keySet()) {
                List<CrossRidLaneDTO> laneDTOS = laneNameMap.get(laneName);
                CrossRidLaneVO crossRidLaneVO = new CrossRidLaneVO();
                crossRidLaneVO.setLaneName(laneName);
                if (ObjectUtil.isEmpty(laneDTOS.get(0).getInDir()) || ObjectUtil.isEmpty(laneDTOS.get(0).getOutDir())) {
                    crossRidLaneVO.setLaneDir(getLaneDir(laneDTOS.get(0).getDir()));
                } else {
                    crossRidLaneVO.setLaneDir(CrossDirEnum.getDesc(laneDTOS.get(0).getInDir()) + CrossDirEnum.getDesc(laneDTOS.get(0).getOutDir()) + "走向");
                }
                crossRidLaneVO.setLaneNum(laneDTOS.size());
                Map<Integer, List<CrossRidLaneDTO>> dirLaneMap = laneDTOS.stream().collect(Collectors.groupingBy(CrossRidLaneDTO::getDir));
                List<LaneDirNumVO> laneDirNumVOS = new ArrayList<>();
                for (Integer dir : dirLaneMap.keySet()) {
                    List<CrossRidLaneDTO> dirLaneDTOS = dirLaneMap.get(dir);
                    LaneDirNumVO laneDirNumVO = new LaneDirNumVO();
                    laneDirNumVO.setLaneInDir(CrossDirEnum.getDesc(dir) + "进口");
                    laneDirNumVO.setLaneDirNum(dirLaneDTOS.size());
                    Map<Integer, List<CrossRidLaneDTO>> turnMap = dirLaneDTOS.stream().collect(Collectors.groupingBy(CrossRidLaneDTO::getTurn));
                    String laneDirTurn = "";
                    for (Integer turn : turnMap.keySet()) {
                        if ("".equals(laneDirTurn)) {
                            laneDirTurn = turnMap.get(turn).size() + LaneTurnEnum.getDesc(turn);
                        } else {
                            laneDirTurn = laneDirTurn + "," + turnMap.get(turn).size() + LaneTurnEnum.getDesc(turn);
                        }
                    }
                    laneDirNumVO.setLaneTurnNum(laneDirTurn);
                    laneDirNumVOS.add(laneDirNumVO);
                }
                crossRidLaneVO.setLaneDirList(laneDirNumVOS);
                crossRidLaneVOS.add(crossRidLaneVO);
            }
            crossRidLaneResult.setCrossRidLaneList(crossRidLaneVOS);
            crossRidLaneResultList.add(crossRidLaneResult);
        }
        return crossRidLaneResultList;
    }

    @Override
    public CrossRunStateAnalysisResultResponseDTO getTotalitySituation(String crossIds, Integer year, Integer week) {
        List<String> crossIdList = null;
        Integer yearWeek = Integer.valueOf("" + year + week);
        Integer yearWeekLast = Integer.valueOf("" + year + (week - 1));
        if (ObjectUtil.isNotEmpty(crossIds)) {
            crossIdList = Arrays.stream(crossIds.split(","))
                    .map(String::trim) // 去除可能的空格
                    .filter(s -> !s.isEmpty()) // 过滤掉空字符串
                    .collect(Collectors.toList());
        }
        CrossRunStateAnalysisResultResponseDTO crossRunStateAnalysisResultResponseDTO = new CrossRunStateAnalysisResultResponseDTO();
        //按周，路口id查询
        List<CrossPeakAnalysis> list = crossRidLaneMapper.getTotalitySituation(crossIdList, yearWeek, null, null);
        List<CrossPeakAnalysis> listLast = crossRidLaneMapper.getTotalitySituation(crossIdList, yearWeekLast, null, null);
        if (ObjectUtil.isEmpty(list)) {
            return null;
        }
        //最大车流路口
        String maxFlowCrossId = "";
        int maxFlowTotal = 0;
        //最大交通指数路口
        String maxTrafficIndexCrossId = "";
        double maxTrafficIndex = 0;
        for (CrossPeakAnalysis crossPeakAnalysis : list) {
            if (crossPeakAnalysis.getDayTotalFlow() > maxFlowTotal) {
                maxFlowTotal = crossPeakAnalysis.getDayTotalFlow();
                maxFlowCrossId = crossPeakAnalysis.getCrossId();
            }
        }
        BaseCrossInfoPO maxFlowTotalBaseCrossInfoPO = maxFlowTotalBaseCrossInfoPO = baseCrossInfoMapper.selectById(maxFlowCrossId);
        crossRunStateAnalysisResultResponseDTO.setMaxFlowCrossName(maxFlowTotalBaseCrossInfoPO.getName());
        for (CrossPeakAnalysis crossPeakAnalysis : list) {
            if (crossPeakAnalysis.getPeakTrafficIndex() > maxTrafficIndex) {
                maxTrafficIndex = crossPeakAnalysis.getDayTotalFlow();
                maxTrafficIndexCrossId = crossPeakAnalysis.getCrossId();
            }
        }
        BaseCrossInfoPO maxTrafficIndexBaseCrossInfoPO = baseCrossInfoMapper.selectById(maxTrafficIndexCrossId);
        crossRunStateAnalysisResultResponseDTO.setMaxTrafficIndexCrossName(maxTrafficIndexBaseCrossInfoPO.getName());

        //按工作日分组
        Map<String, List<CrossPeakAnalysis>> dayTypeMap = list.stream().collect(Collectors.groupingBy(CrossPeakAnalysis::getDayType));
        Map<String, List<CrossPeakAnalysis>> dayTypeMapLast = listLast.stream().collect(Collectors.groupingBy(CrossPeakAnalysis::getDayType));
        double workTotalFlow = 0;
        double workTotalFlowLast = 0;
        int workDayAmPeakMaxHourFlow = 0;
        int workDayAmPeakMaxHourFlowLast = 0;
        int workDayPmPeakMaxHourFlow = 0;
        int workDayPmPeakMaxHourFlowLast = 0;
        int workDayFmPeakMaxHourFlow = 0;
        int workDayFmPeakMaxHourFlowLast = 0;
        double weekEndAvgFlow = 0;
        double weekEndAvgFlowLast = 0;
        double workDayAmPeakAvgTrafficIndex = 0;
        double workDayAmPeakAvgTrafficIndexLast = 0;
        double workDayPmPeakAvgTrafficIndex = 0;
        double workDayPmPeakAvgTrafficIndexLast = 0;

        if (ObjectUtil.isNotEmpty(dayTypeMap.get("1"))) {
            //工作日平均流量
            workTotalFlow = dayTypeMap.get("1").stream().mapToInt(CrossPeakAnalysis::getDayTotalFlow).average().orElse(0.0);
            //工作日高峰最大小时流量
            Map<String, Integer> peakMaxHourFlowByPeak = dayTypeMap.get("1").stream().collect(
                    Collectors.groupingBy(CrossPeakAnalysis::getDayType, // 按 dayType 分组
                            Collectors.collectingAndThen( // 对分组后的数据进行进一步处理
                                    Collectors.maxBy(Comparator.comparingInt(CrossPeakAnalysis::getPeakMaxHourFlow)), // 找到每组的最大值
                                    optionalAnalysis -> optionalAnalysis.map(CrossPeakAnalysis::getPeakMaxHourFlow).orElse(0) // 提取最大值并提供默认值
                            )));
            //工作日高峰平均交通指数
            Map<String, Double> workDayPeakAvgTrafficIndexBypeak = dayTypeMap.get("1").stream().collect(
                    Collectors.groupingBy(
                            CrossPeakAnalysis::getDayType, // 按 dayType 分组
                            Collectors.averagingDouble(CrossPeakAnalysis::getPeakTrafficIndex)
                    ));
            workDayAmPeakMaxHourFlow = ObjectUtil.isEmpty(peakMaxHourFlowByPeak.get("1")) ? 0 : peakMaxHourFlowByPeak.get("1");
            workDayPmPeakMaxHourFlow = ObjectUtil.isEmpty(peakMaxHourFlowByPeak.get("2")) ? 0 : peakMaxHourFlowByPeak.get("2");
            workDayFmPeakMaxHourFlow = ObjectUtil.isEmpty(peakMaxHourFlowByPeak.get("3")) ? 0 : peakMaxHourFlowByPeak.get("3");
            workDayAmPeakAvgTrafficIndex = ObjectUtil.isEmpty(workDayPeakAvgTrafficIndexBypeak.get("1")) ? 0 : workDayPeakAvgTrafficIndexBypeak.get("1");
            workDayPmPeakAvgTrafficIndex = ObjectUtil.isEmpty(workDayPeakAvgTrafficIndexBypeak.get("2")) ? 0 : workDayPeakAvgTrafficIndexBypeak.get("2");
        }
        if (ObjectUtil.isNotEmpty(dayTypeMapLast.get("1"))) {
            //上周工作日平均流量
            workTotalFlowLast = dayTypeMapLast.get("1").stream().mapToInt(CrossPeakAnalysis::getDayTotalFlow).average().orElse(0.0);
            //上周工作日高峰最大小时流量
            Map<String, Integer> peakMaxHourFlowByPeakLast = dayTypeMapLast.get("1").stream().collect(
                    Collectors.groupingBy(CrossPeakAnalysis::getDayType, // 按 dayType 分组
                            Collectors.collectingAndThen( // 对分组后的数据进行进一步处理
                                    Collectors.maxBy(Comparator.comparingInt(CrossPeakAnalysis::getPeakMaxHourFlow)), // 找到每组的最大值
                                    optionalAnalysis -> optionalAnalysis.map(CrossPeakAnalysis::getPeakMaxHourFlow).orElse(0) // 提取最大值并提供默认值
                            )));
            //上周工作日高峰平均交通指数
            Map<String, Double> workDayPeakAvgTrafficIndexBypeakLast = dayTypeMapLast.get("1").stream().collect(
                    Collectors.groupingBy(
                            CrossPeakAnalysis::getDayType, // 按 dayType 分组
                            Collectors.averagingDouble(CrossPeakAnalysis::getPeakTrafficIndex)
                    ));
            workDayAmPeakMaxHourFlowLast = ObjectUtil.isEmpty(peakMaxHourFlowByPeakLast.get("1")) ? 0 : peakMaxHourFlowByPeakLast.get("1");
            workDayPmPeakMaxHourFlowLast = ObjectUtil.isEmpty(peakMaxHourFlowByPeakLast.get("2")) ? 0 : peakMaxHourFlowByPeakLast.get("2");
            workDayFmPeakMaxHourFlowLast = ObjectUtil.isEmpty(peakMaxHourFlowByPeakLast.get("3")) ? 0 : peakMaxHourFlowByPeakLast.get("3");
            workDayAmPeakAvgTrafficIndexLast = ObjectUtil.isEmpty(workDayPeakAvgTrafficIndexBypeakLast.get("1")) ? 0 : workDayPeakAvgTrafficIndexBypeakLast.get("1");
            workDayPmPeakAvgTrafficIndexLast = ObjectUtil.isEmpty(workDayPeakAvgTrafficIndexBypeakLast.get("2")) ? 0 : workDayPeakAvgTrafficIndexBypeakLast.get("2");
        }
        if (ObjectUtil.isNotEmpty(dayTypeMap.get("2"))) {
            //周末车流量
            weekEndAvgFlow = dayTypeMap.get("2").stream().mapToInt(CrossPeakAnalysis::getDayTotalFlow).average().orElse(0.0);
        }
        if (ObjectUtil.isNotEmpty(dayTypeMapLast.get("2"))) {
            //上周周末车流量
            weekEndAvgFlowLast = dayTypeMapLast.get("2").stream().mapToInt(CrossPeakAnalysis::getDayTotalFlow).average().orElse(0.0);
        }

        //工作日平均车流差
        double workTotalFlowSum = workTotalFlow - workTotalFlowLast;
        //周末平均车流差
        double weekEndAvgFlowSum = weekEndAvgFlow - weekEndAvgFlowLast;

        int workDayAmPeakMaxHourFlowSum = workDayAmPeakMaxHourFlow - workDayAmPeakMaxHourFlowLast;
        int workDayPmPeakMaxHourFlowSum = workDayPmPeakMaxHourFlow - workDayPmPeakMaxHourFlowLast;
        int workDayFmPeakMaxHourFlowSum = workDayFmPeakMaxHourFlow - workDayFmPeakMaxHourFlowLast;
        double workDayAmPeakAvgTrafficIndexSum = workDayAmPeakAvgTrafficIndex - workDayAmPeakAvgTrafficIndexLast;
        double workDayPmPeakAvgTrafficIndexSum = workDayPmPeakAvgTrafficIndex - workDayPmPeakAvgTrafficIndexLast;

        //工作日、周末车流
        crossRunStateAnalysisResultResponseDTO.setWorkDayAvgFlow(String.valueOf(Math.round(workTotalFlow)) + "辆");
        crossRunStateAnalysisResultResponseDTO.setWeekEndAvgFlow(String.valueOf(Math.round(weekEndAvgFlow)) + "辆");

        crossRunStateAnalysisResultResponseDTO.setWorkDayAmPeakMaxHourFlow(String.valueOf(workDayAmPeakMaxHourFlow) + "辆");
        crossRunStateAnalysisResultResponseDTO.setWorkDayPmPeakMaxHourFlow(String.valueOf(workDayPmPeakMaxHourFlow) + "辆");
        crossRunStateAnalysisResultResponseDTO.setWorkDayFmPeakMaxHourFlow(String.valueOf(workDayFmPeakMaxHourFlow) + "辆");
        crossRunStateAnalysisResultResponseDTO.setWorkDayAmPeakAvgTrafficIndex(String.valueOf(Math.round(workDayAmPeakAvgTrafficIndex * 100) / 100.0));
        crossRunStateAnalysisResultResponseDTO.setWorkDayPmPeakAvgTrafficIndex(String.valueOf(Math.round(workDayPmPeakAvgTrafficIndex * 100) / 100.0));

        if (workTotalFlowSum > 0) {
            crossRunStateAnalysisResultResponseDTO.setAvgFlowLastWeekCompare("提升" + Math.round(workTotalFlowSum) + "辆");
        } else {
            crossRunStateAnalysisResultResponseDTO.setAvgFlowLastWeekCompare("下降" + Math.abs(Math.round(workTotalFlowSum)) + "辆");
        }
        if (weekEndAvgFlowSum > 0) {
            crossRunStateAnalysisResultResponseDTO.setEndAvgFlowLastWeekCompare("提升" + Math.round(weekEndAvgFlowSum) + "辆");
        } else {
            crossRunStateAnalysisResultResponseDTO.setEndAvgFlowLastWeekCompare("下降" + Math.abs(Math.round(weekEndAvgFlowSum)) + "辆");
        }
        if (workDayAmPeakMaxHourFlowSum > 0) {
            crossRunStateAnalysisResultResponseDTO.setAmPeakMaxHourFlowLastWeekCompare("提升" + workDayAmPeakMaxHourFlowSum + "辆");
        } else {
            crossRunStateAnalysisResultResponseDTO.setAmPeakMaxHourFlowLastWeekCompare("下降" + Math.abs(workDayAmPeakMaxHourFlowSum) + "辆");
        }
        if (workDayPmPeakMaxHourFlowSum > 0) {
            crossRunStateAnalysisResultResponseDTO.setPmPeakMaxHourFlowLastWeekCompare("提升" + workDayPmPeakMaxHourFlowSum + "辆");
        } else {
            crossRunStateAnalysisResultResponseDTO.setPmPeakMaxHourFlowLastWeekCompare("下降" + Math.abs(workDayPmPeakMaxHourFlowSum) + "辆");
        }
        if (workDayFmPeakMaxHourFlowSum > 0) {
            crossRunStateAnalysisResultResponseDTO.setFmPeakMaxHourFlowLastWeekCompare("提升" + workDayFmPeakMaxHourFlowSum + "辆");
        } else {
            crossRunStateAnalysisResultResponseDTO.setFmPeakMaxHourFlowLastWeekCompare("下降" + Math.abs(workDayFmPeakMaxHourFlowSum) + "辆");
        }
        if (workDayAmPeakAvgTrafficIndexSum > 0) {
            if (workDayAmPeakAvgTrafficIndexLast == 0) {
                crossRunStateAnalysisResultResponseDTO.setAmPeakAvgTrafficIndexLastWeekCompare("提升100%");
            } else {
                crossRunStateAnalysisResultResponseDTO.setAmPeakAvgTrafficIndexLastWeekCompare("提升" + Math.round(workDayAmPeakAvgTrafficIndexSum * 100 / workDayAmPeakAvgTrafficIndexLast * 100) / 100.0 + "%");
            }
        } else {
            if (workDayAmPeakAvgTrafficIndexLast == 0) {
                crossRunStateAnalysisResultResponseDTO.setAmPeakAvgTrafficIndexLastWeekCompare("下降0%");
            } else {
                crossRunStateAnalysisResultResponseDTO.setAmPeakAvgTrafficIndexLastWeekCompare("下降" + Math.abs(Math.round(workDayAmPeakAvgTrafficIndexSum * 100 / workDayAmPeakAvgTrafficIndexLast * 100) / 100.0) + "%");
            }
        }
        if (workDayPmPeakAvgTrafficIndexSum > 0) {
            if (workDayPmPeakAvgTrafficIndexLast == 0) {
                crossRunStateAnalysisResultResponseDTO.setPmPeakAvgTrafficIndexLastWeekCompare("提升100%");
            } else {
                crossRunStateAnalysisResultResponseDTO.setPmPeakAvgTrafficIndexLastWeekCompare("提升" + Math.round(workDayPmPeakAvgTrafficIndexSum * 100 / workDayAmPeakAvgTrafficIndexLast * 100) / 100.0 + "%");
            }
        } else {
            if (workDayPmPeakAvgTrafficIndexLast == 0) {
                crossRunStateAnalysisResultResponseDTO.setPmPeakAvgTrafficIndexLastWeekCompare("下降0%");
            } else {
                crossRunStateAnalysisResultResponseDTO.setPmPeakAvgTrafficIndexLastWeekCompare("下降" + Math.abs(Math.round(workDayPmPeakAvgTrafficIndexSum * 100 / workDayPmPeakAvgTrafficIndexLast * 100) / 100.0) + "%");
            }
        }

        Map<String, List<CrossPeakAnalysis>> crossIdMap = list.stream().collect(Collectors.groupingBy(CrossPeakAnalysis::getCrossId));
        Map<String, List<CrossPeakAnalysis>> crossIdMapLast = listLast.stream().collect(Collectors.groupingBy(CrossPeakAnalysis::getCrossId));
        List<CrossRunStateDetailAnalysisDataDTO> crossRunStateDetailAnalysisDataDTOS = new ArrayList<>();
        if (ObjectUtil.isNotEmpty(crossIdMap)) {
            for (String crossId : crossIdMap.keySet()) {
                CrossRunStateDetailAnalysisDataDTO crossRunStateDetailAnalysisDataDTO = new CrossRunStateDetailAnalysisDataDTO();
                BaseCrossInfoPO baseCrossInfoPO = baseCrossInfoMapper.selectById(crossId);
                crossRunStateDetailAnalysisDataDTO.setCrossName(baseCrossInfoPO.getName());
                List<CrossPeakAnalysis> crossPeakAnalyses = crossIdMap.get(crossId);
                List<CrossPeakAnalysis> crossPeakAnalysesLast = crossIdMapLast.get(crossId);
                int thisWeekPeakMaxFlow = 0;
                int lastWeekPeakMaxFlow = 0;
                int thisWeekEndMaxFlow = 0;
                int lastWeekEndMaxFlow = 0;
                double thisWeekWorkDayAmTrafficIndex = 0;
                int thisWeekWorkDayAmTrafficIndexCount = 0;
                double lastWeekWorkDayAmTrafficIndex = 0;
                int lastWeekWorkDayAmTrafficIndexCount = 0;
                double thisWeekWorkDayPmTrafficIndex = 0;
                int thisWeekWorkDayPmTrafficIndexCount = 0;
                double lastWeekWorkDayPmTrafficIndex = 0;
                int lastWeekWorkDayPmTrafficIndexCount = 0;
                if (ObjectUtil.isNotEmpty(crossPeakAnalyses)) {
                    for (CrossPeakAnalysis crossPeakAnalysis : crossPeakAnalyses) {
                        if (crossPeakAnalysis.getDayType().equals("1")) {
                            if (crossPeakAnalysis.getPeakMaxHourFlow() > thisWeekPeakMaxFlow) {
                                thisWeekPeakMaxFlow = crossPeakAnalysis.getPeakMaxHourFlow();
                            }
                            if (crossPeakAnalysis.getPeakType().equals("1")) {
                                thisWeekWorkDayAmTrafficIndexCount++;
                                thisWeekWorkDayAmTrafficIndex += crossPeakAnalysis.getPeakTrafficIndex();
                            }
                            if (crossPeakAnalysis.getPeakType().equals("2")) {
                                thisWeekWorkDayPmTrafficIndexCount++;
                                thisWeekWorkDayPmTrafficIndex += crossPeakAnalysis.getPeakTrafficIndex();
                            }
                        }
                        if (crossPeakAnalysis.getDayType().equals("2")) {
                            if (crossPeakAnalysis.getPeakMaxHourFlow() > thisWeekEndMaxFlow) {
                                thisWeekEndMaxFlow = crossPeakAnalysis.getPeakMaxHourFlow();
                            }
                        }
                    }
                }
                if (ObjectUtil.isNotEmpty(crossPeakAnalysesLast)) {
                    for (CrossPeakAnalysis crossPeakAnalysis : crossPeakAnalysesLast) {
                        if (crossPeakAnalysis.getDayType().equals("1")) {
                            if (crossPeakAnalysis.getPeakMaxHourFlow() > lastWeekPeakMaxFlow) {
                                lastWeekEndMaxFlow = crossPeakAnalysis.getPeakMaxHourFlow();
                            }
                            if (crossPeakAnalysis.getPeakType().equals("1")) {
                                lastWeekWorkDayAmTrafficIndexCount++;
                                lastWeekWorkDayAmTrafficIndex += crossPeakAnalysis.getPeakTrafficIndex();
                            }
                            if (crossPeakAnalysis.getPeakType().equals("2")) {
                                lastWeekWorkDayPmTrafficIndexCount++;
                                lastWeekWorkDayPmTrafficIndex += crossPeakAnalysis.getPeakTrafficIndex();
                            }
                        }
                        if (crossPeakAnalysis.getDayType().equals("2")) {
                            if (crossPeakAnalysis.getPeakMaxHourFlow() > lastWeekEndMaxFlow) {
                                lastWeekEndMaxFlow = crossPeakAnalysis.getPeakMaxHourFlow();
                            }
                        }
                    }
                }

                crossRunStateDetailAnalysisDataDTO.setThisWeekPeakMaxFlow(thisWeekPeakMaxFlow);
                crossRunStateDetailAnalysisDataDTO.setLastWeekPeakMaxFlow(lastWeekPeakMaxFlow);
                crossRunStateDetailAnalysisDataDTO.setThisWeekEndMaxFlow(thisWeekEndMaxFlow);
                crossRunStateDetailAnalysisDataDTO.setLastWeekEndMaxFlow(lastWeekEndMaxFlow);

                if (thisWeekWorkDayAmTrafficIndexCount == 0) {
                    crossRunStateDetailAnalysisDataDTO.setThisWeekWorkDayAmTrafficIndex(0.0);
                } else {
                    crossRunStateDetailAnalysisDataDTO.setThisWeekWorkDayAmTrafficIndex(Math.round(thisWeekWorkDayAmTrafficIndex / thisWeekWorkDayAmTrafficIndexCount * 100) / 100.0);
                }
                if (lastWeekWorkDayAmTrafficIndexCount == 0) {
                    crossRunStateDetailAnalysisDataDTO.setLastWeekWorkDayAmTrafficIndex(0.0);
                } else {
                    crossRunStateDetailAnalysisDataDTO.setLastWeekWorkDayAmTrafficIndex(Math.round(lastWeekWorkDayAmTrafficIndex / lastWeekWorkDayAmTrafficIndexCount * 100) / 100.0);
                }
                if (thisWeekWorkDayPmTrafficIndexCount == 0) {
                    crossRunStateDetailAnalysisDataDTO.setThisWeekWorkDayPmTrafficIndex(0.0);
                } else {
                    crossRunStateDetailAnalysisDataDTO.setThisWeekWorkDayPmTrafficIndex(Math.round(thisWeekWorkDayPmTrafficIndex / thisWeekWorkDayPmTrafficIndexCount * 100) / 100.0);
                }
                if (lastWeekWorkDayPmTrafficIndexCount == 0) {
                    crossRunStateDetailAnalysisDataDTO.setLastWeekWorkDayPmTrafficIndex(0.0);
                } else {
                    crossRunStateDetailAnalysisDataDTO.setLastWeekWorkDayPmTrafficIndex(Math.round(lastWeekWorkDayPmTrafficIndex / lastWeekWorkDayPmTrafficIndexCount * 100) / 100.0);
                }

                crossRunStateDetailAnalysisDataDTOS.add(crossRunStateDetailAnalysisDataDTO);
            }
        }
        // 排序并设置排序序号
        AtomicInteger flowSort = new AtomicInteger(1); // 使用原子整数作为计数器
        crossRunStateDetailAnalysisDataDTOS.stream().sorted(Comparator.comparingInt(CrossRunStateDetailAnalysisDataDTO::getThisWeekPeakMaxFlow)).forEach(x -> {
            x.setFlowSort(flowSort.getAndIncrement());
        });
        AtomicInteger indexSort = new AtomicInteger(1); // 使用原子整数作为计数器
        crossRunStateDetailAnalysisDataDTOS.stream().sorted(Comparator.comparingDouble(CrossRunStateDetailAnalysisDataDTO::getThisWeekWorkDayAmTrafficIndex)).forEach(x -> {
            x.setTrafficIndexSort(indexSort.getAndIncrement());
        });

        crossRunStateAnalysisResultResponseDTO.setDataList(crossRunStateDetailAnalysisDataDTOS);
        return crossRunStateAnalysisResultResponseDTO;
    }

    private SimpleDateFormat format = new SimpleDateFormat("HH:mm");

    @Override
    public List<CrossRunStatePeakResultResponseVO> getPeakData(String crossIds, Integer year, Integer week) {
        List<String> crossIdList = null;
        Integer yearWeek = Integer.valueOf("" + year + week);
        Integer yearWeekLast = Integer.valueOf("" + year + (week - 1));
        if (ObjectUtil.isNotEmpty(crossIds)) {
            crossIdList = Arrays.stream(crossIds.split(","))
                    .map(String::trim) // 去除可能的空格
                    .filter(s -> !s.isEmpty()) // 过滤掉空字符串
                    .collect(Collectors.toList());
        }
        List<AnalysisReportCrossPeakDetail> analysisReportCrossPeakDetailList = crossRidLaneMapper.getPeakData(crossIdList, yearWeek);
        List<AnalysisReportCrossPeakDetail> analysisReportCrossPeakDetailListLast = crossRidLaneMapper.getPeakData(crossIdList, yearWeekLast);
        List<CrossRunStatePeakResultResponseVO> crossRunStatePeakResultResponseVOList = new ArrayList<>();
        Map<String, List<AnalysisReportCrossPeakDetail>> crossIdMap = analysisReportCrossPeakDetailList.stream().collect(Collectors.groupingBy(AnalysisReportCrossPeakDetail::getCrossId));
        Map<String, List<AnalysisReportCrossPeakDetail>> crossIdMapLast = analysisReportCrossPeakDetailListLast.stream().collect(Collectors.groupingBy(AnalysisReportCrossPeakDetail::getCrossId));
        for (String crossId : crossIdMap.keySet()) {
            if (ObjectUtil.isEmpty(crossId)) {
                continue;
            }
            List<AnalysisReportCrossPeakDetail> peakDetails = crossIdMap.get(crossId);
            List<AnalysisReportCrossPeakDetail> peakDetailsLast = ObjectUtil.isEmpty(crossIdMapLast.get(crossId)) ? new ArrayList<>() : crossIdMapLast.get(crossId);
            CrossRunStatePeakResultResponseVO peakResultResponseVO = new CrossRunStatePeakResultResponseVO();
            peakDetails.forEach(x -> {
                if (ObjectUtil.isEmpty(x.getPeakCapacity())) {
                    x.setPeakCapacity(0);
                }
            });
            //路口名称
            BaseCrossInfoPO baseCrossInfoPO = baseCrossInfoMapper.selectById(crossId);
            peakResultResponseVO.setCrossName(baseCrossInfoPO.getName());
            double amPeakAvgTrafficIndexLastWeekCompare = 0;
            double pmPeakAvgTrafficIndexLastWeekCompare = 0;
            //工作日早高峰平均交通指数与上周比较情况增加【减少】10%
            double amPeakTrafficIndex = peakDetails.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "1".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakTrafficIndex).average().orElse(0.0);
            double amPeakTrafficIndexLast = peakDetailsLast.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "1".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakTrafficIndex).average().orElse(0.0);
            if (amPeakTrafficIndexLast == 0) {
                peakResultResponseVO.setAmPeakAvgTrafficIndexLastWeekCompare("增加100%");
            } else {
                amPeakAvgTrafficIndexLastWeekCompare = (amPeakTrafficIndex - amPeakTrafficIndexLast) / amPeakTrafficIndexLast;
                if (amPeakAvgTrafficIndexLastWeekCompare > 0) {
                    peakResultResponseVO.setAmPeakAvgTrafficIndexLastWeekCompare("增加" + Math.round(amPeakAvgTrafficIndexLastWeekCompare * 100) + "%");
                } else {
                    peakResultResponseVO.setAmPeakAvgTrafficIndexLastWeekCompare("减少" + Math.abs(Math.round(amPeakAvgTrafficIndexLastWeekCompare * 100)) + "%");
                }
            }
            //工作日晚高峰平均交通指数与上周比较情况,增加【减少】10%
            double pmPeakTrafficIndex = peakDetails.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "2".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakTrafficIndex).average().orElse(0.0);
            double pmPeakTrafficIndexLast = peakDetailsLast.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "2".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakTrafficIndex).average().orElse(0.0);
            if (pmPeakTrafficIndexLast == 0) {
                peakResultResponseVO.setPmPeakAvgTrafficIndexLastWeekCompare("增加100%");
            } else {
                pmPeakAvgTrafficIndexLastWeekCompare = (pmPeakTrafficIndex - pmPeakTrafficIndexLast) / pmPeakTrafficIndexLast;
                if (pmPeakAvgTrafficIndexLastWeekCompare > 0) {
                    peakResultResponseVO.setPmPeakAvgTrafficIndexLastWeekCompare("增加" + Math.round(pmPeakAvgTrafficIndexLastWeekCompare * 100) + "%");
                } else {
                    peakResultResponseVO.setPmPeakAvgTrafficIndexLastWeekCompare("减少" + Math.abs(Math.round(pmPeakAvgTrafficIndexLastWeekCompare * 100)) + "%");
                }
            }

            //工作日早高峰通行能力与上周比较情况,提升【下降】5%
            double amPeakCapacity = peakDetails.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "1".equals(x.getPeakType());
            }).mapToDouble(x -> {
                return ObjectUtil.isEmpty(x.getPeakCapacity()) ? 0.0 : x.getPeakCapacity();
            }).average().orElse(0.0);
            double amPeakCapacityLast = peakDetailsLast.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "1".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakCapacity).average().orElse(0.0);
            if (amPeakCapacityLast == 0) {
                peakResultResponseVO.setAmPeakCapacityLastWeekCompare("提升100%");
            } else {
                double amPeakCapacityLastWeekCompare = (amPeakCapacity - amPeakCapacityLast) / amPeakCapacityLast;
                if (amPeakCapacityLastWeekCompare > 0) {
                    peakResultResponseVO.setAmPeakCapacityLastWeekCompare("提升" + Math.round(amPeakCapacityLastWeekCompare * 100) + "%");
                } else {
                    peakResultResponseVO.setAmPeakCapacityLastWeekCompare("下降" + Math.abs(Math.round(amPeakCapacityLastWeekCompare * 100)) + "%");
                }
            }

            //工作日晚高峰通行能力与上周比较情况提升【下降】5%
            double pmPeakCapacity = peakDetails.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "2".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakCapacity).average().orElse(0.0);
            double pmPeakCapacityLast = peakDetailsLast.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "2".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakCapacity).average().orElse(0.0);
            if (pmPeakCapacityLast == 0) {
                peakResultResponseVO.setPmPeakCapacityLastWeekCompare("提升100%");
            } else {
                double pmPeakCapacityLastWeekCompare = (pmPeakCapacity - pmPeakCapacityLast) / pmPeakCapacityLast;
                if (pmPeakCapacityLastWeekCompare > 0) {
                    peakResultResponseVO.setPmPeakCapacityLastWeekCompare("提升" + Math.round(pmPeakCapacityLastWeekCompare * 100) + "%");
                } else {
                    peakResultResponseVO.setPmPeakCapacityLastWeekCompare("下降" + Math.abs(Math.round(pmPeakCapacityLastWeekCompare * 100)) + "%");
                }
            }

            //工作日早高峰平均延误与上周比较情况增加【减少】11%
            double amPeakDelayTime = peakDetails.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "1".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakAvgDeayTime).average().orElse(0.0);
            double amPeakDelayTimeLast = peakDetailsLast.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "1".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakAvgDeayTime).average().orElse(0.0);
            if (amPeakDelayTimeLast == 0) {
                peakResultResponseVO.setAmPeakDelayTimeLastWeekCompare("增加100%");
            } else {
                double amPeakDelayTimeLastWeekCompare = (amPeakDelayTime - amPeakDelayTimeLast) / amPeakDelayTimeLast;
                if (amPeakDelayTimeLastWeekCompare > 0) {
                    peakResultResponseVO.setAmPeakDelayTimeLastWeekCompare("增加" + Math.round(amPeakDelayTimeLastWeekCompare * 100) + "%");
                } else {
                    peakResultResponseVO.setAmPeakDelayTimeLastWeekCompare("减少" + Math.abs(Math.round(amPeakDelayTimeLastWeekCompare * 100)) + "%");
                }
            }

            //工作日晚高峰平均延误与上周比较情况,增加【减少】11%
            double pmPeakDelayTime = peakDetails.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "2".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakAvgDeayTime).average().orElse(0.0);
            double pmPeakDelayTimeLast = peakDetailsLast.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "2".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakAvgDeayTime).average().orElse(0.0);
            if (pmPeakDelayTimeLast == 0) {
                peakResultResponseVO.setPmPeakDelayTimeLastWeekCompare("增加100%");
            } else {
                double pmPeakDelayTimeLastWeekCompare = (pmPeakDelayTime - pmPeakDelayTimeLast) / pmPeakDelayTimeLast;
                if (pmPeakDelayTimeLastWeekCompare > 0) {
                    peakResultResponseVO.setPmPeakDelayTimeLastWeekCompare("增加" + Math.round(pmPeakDelayTimeLastWeekCompare * 100) + "%");
                } else {
                    peakResultResponseVO.setPmPeakDelayTimeLastWeekCompare("减少" + Math.abs(Math.round(pmPeakDelayTimeLastWeekCompare * 100)) + "%");
                }
            }

            //工作日早高峰最大排队与上周比较情况,增加【减少】11%
            double amPeakMaxQueueLength = peakDetails.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "1".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakMaxQueueLength).average().orElse(0.0);
            double amPeakMaxQueueLengthLast = peakDetailsLast.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "1".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakMaxQueueLength).average().orElse(0.0);
            if (amPeakMaxQueueLengthLast == 0) {
                peakResultResponseVO.setAmPeakMaxQueueLengthLastWeekCompare("增加100%");
            } else {
                double amPeakMaxQueueLengthLastWeekCompare = (amPeakMaxQueueLength - amPeakMaxQueueLengthLast) / amPeakMaxQueueLengthLast;
                if (amPeakMaxQueueLengthLastWeekCompare > 0) {
                    peakResultResponseVO.setAmPeakMaxQueueLengthLastWeekCompare("增加" + Math.round(amPeakMaxQueueLengthLastWeekCompare * 100) + "%");
                } else {
                    peakResultResponseVO.setAmPeakMaxQueueLengthLastWeekCompare("减少" + Math.abs(Math.round(amPeakMaxQueueLengthLastWeekCompare * 100)) + "%");
                }
            }

            //工作日晚高峰最大排队与上周比较情况增加【减少】11%
            double pmPeakMaxQueueLength = peakDetails.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "2".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakMaxQueueLength).average().orElse(0.0);
            double pmPeakMaxQueueLengthLast = peakDetailsLast.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "2".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakMaxQueueLength).average().orElse(0.0);
            if (pmPeakMaxQueueLengthLast == 0) {
                peakResultResponseVO.setPmPeakMaxQueueLengthLastWeekCompare("增加100%");
            } else {
                double pmPeakMaxQueueLengthLastWeekCompare = (pmPeakMaxQueueLength - pmPeakMaxQueueLengthLast) / pmPeakMaxQueueLengthLast;
                if (pmPeakMaxQueueLengthLastWeekCompare > 0) {
                    peakResultResponseVO.setPmPeakMaxQueueLengthLastWeekCompare("增加" + Math.round(pmPeakMaxQueueLengthLastWeekCompare * 100) + "%");
                } else {
                    peakResultResponseVO.setPmPeakMaxQueueLengthLastWeekCompare("减少" + Math.abs(Math.round(pmPeakMaxQueueLengthLastWeekCompare * 100)) + "%");
                }
            }

            //工作日早高峰停车次数与上周比较情况增加【减少】5%
            double amPeakStopTimes = peakDetails.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "1".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakAvgStopTimes).average().orElse(0.0);
            double amPeakStopTimesLast = peakDetailsLast.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "1".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakAvgStopTimes).average().orElse(0.0);
            if (amPeakStopTimesLast == 0) {
                peakResultResponseVO.setAmPeakStopTimesLastWeekCompare("增加100%");
            } else {
                double amPeakStopTimesLastWeekCompare = (amPeakStopTimes - amPeakStopTimesLast) / amPeakStopTimesLast;
                if (amPeakStopTimesLastWeekCompare > 0) {
                    peakResultResponseVO.setAmPeakStopTimesLastWeekCompare("增加" + Math.round(amPeakStopTimesLastWeekCompare * 100) + "%");
                } else {
                    peakResultResponseVO.setAmPeakStopTimesLastWeekCompare("减少" + Math.abs(Math.round(amPeakStopTimesLastWeekCompare * 100)) + "%");
                }
            }

            //工作日晚高峰停车次数与上周比较情况增加【减少】5%
            double pmPeakStopTimes = peakDetails.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "2".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakAvgStopTimes).average().orElse(0.0);
            double pmPeakStopTimesLast = peakDetailsLast.stream().filter(x -> {
                return "1".equals(x.getDayType()) && "2".equals(x.getPeakType());
            }).mapToDouble(AnalysisReportCrossPeakDetail::getPeakAvgStopTimes).average().orElse(0.0);
            if (pmPeakStopTimesLast == 0) {
                peakResultResponseVO.setPmPeakStopTimesLastWeekCompare("增加100%");
            } else {
                double pmPeakStopTimesLastWeekCompare = (pmPeakStopTimes - pmPeakStopTimesLast) / pmPeakStopTimesLast;
                if (pmPeakStopTimesLastWeekCompare > 0) {
                    peakResultResponseVO.setPmPeakStopTimesLastWeekCompare("增加" + Math.round(pmPeakStopTimesLastWeekCompare * 100) + "%");
                } else {
                    peakResultResponseVO.setPmPeakStopTimesLastWeekCompare("减少" + Math.abs(Math.round(pmPeakStopTimesLastWeekCompare * 100)) + "%");
                }
            }
            //总体运行效果明显提升【略有下降】
            if (pmPeakTrafficIndex + amPeakTrafficIndex - amPeakTrafficIndexLast - pmPeakTrafficIndexLast > 0) {
                peakResultResponseVO.setTotalityRunSituation("明显提升");
            } else if (pmPeakTrafficIndex + amPeakTrafficIndex - amPeakTrafficIndexLast - pmPeakTrafficIndexLast == 0) {
                peakResultResponseVO.setTotalityRunSituation("持平");
            } else {
                peakResultResponseVO.setTotalityRunSituation("略有下降");
            }
            //本周早高峰集中时段7:30~8:30
            List<String> timeList = new ArrayList<>();
            List<String> timeListLast = new ArrayList<>();
            peakDetails.stream().filter(x -> {
                return "1".equals(x.getPeakType());
            }).forEach(x -> {
                String timeString = getTimeString(x);
                timeList.add(timeString);
            });
            peakDetailsLast.stream().filter(x -> {
                return "1".equals(x.getPeakType());
            }).forEach(x -> {
                String timeString = getTimeString(x);
                timeListLast.add(timeString);
            });
            String timeString = TimeIntervalMerger.toTimeString(timeList);
            String timeStringLast = TimeIntervalMerger.toTimeString(timeListLast);
            peakResultResponseVO.setThisWeekAmPeakTimeSpan(timeString);

            //本周早高峰集中时段持续时长,45分钟
            String[] timeSpans = timeString.split("~");
            String[] timeSpansLast = timeStringLast.split("~");
            Long thisWeekAmPeakDuration = 0L;
            if (ObjectUtil.isNotEmpty(timeString)) {
                thisWeekAmPeakDuration = getTimeSum(timeSpans[0], timeSpans[1]);
            }
            Long thisWeekAmPeakDurationLast = 0L;
            if (ObjectUtil.isNotEmpty(timeStringLast)) {
                thisWeekAmPeakDurationLast = getTimeSum(timeSpansLast[0], timeSpansLast[1]);
            }
            peakResultResponseVO.setThisWeekAmPeakDuration(thisWeekAmPeakDuration + "分钟");

            //本周早高峰时段开始时间上周比较情况提前【延后】20分钟
            Long thisWeekAmPeakStartTimeSituation = getTimeSum(timeSpansLast[0], timeSpans[0]);
            if (thisWeekAmPeakStartTimeSituation > 0) {
                peakResultResponseVO.setThisWeekAmPeakStartTimeSituation("延后" + thisWeekAmPeakStartTimeSituation + "分钟");
            } else {
                peakResultResponseVO.setThisWeekAmPeakStartTimeSituation("提前" + Math.abs(thisWeekAmPeakStartTimeSituation) + "分钟");
            }

            //本周早高峰时段结束时间上周比较情况提前【延后】20分钟
            Long thisWeekAmPeakEndTimeSituation = getTimeSum(timeSpansLast[0], timeSpans[0]);
            if (thisWeekAmPeakEndTimeSituation > 0) {
                peakResultResponseVO.setThisWeekAmPeakEndTimeSituation("延后" + thisWeekAmPeakEndTimeSituation + "分钟");
            } else {
                peakResultResponseVO.setThisWeekAmPeakEndTimeSituation("提前" + Math.abs(thisWeekAmPeakEndTimeSituation) + "分钟");
            }

            //本周早高峰持续时长上周比较情况提前【延后】20分钟
            Long thisWeekAmPeakDurationSituation = thisWeekAmPeakDuration - thisWeekAmPeakDurationLast;
            if (thisWeekAmPeakDurationSituation > 0) {
                peakResultResponseVO.setThisWeekAmPeakDurationSituation("延后" + thisWeekAmPeakDurationSituation + "分钟");
            } else {
                peakResultResponseVO.setThisWeekAmPeakDurationSituation("提前" + Math.abs(thisWeekAmPeakDurationSituation) + "分钟");
            }

            //本周晚高峰集中时段7:30~8:30
            List<String> timePmList = new ArrayList<>();
            List<String> timePmListLast = new ArrayList<>();
            peakDetails.stream().filter(x -> {
                return "2".equals(x.getPeakType());
            }).forEach(x -> {
                String timePmString = getTimeString(x);
                timePmList.add(timePmString);
            });
            peakDetailsLast.stream().filter(x -> {
                return "2".equals(x.getPeakType());
            }).forEach(x -> {
                String timePmString = getTimeString(x);
                timePmListLast.add(timePmString);
            });
            String timePmString = TimeIntervalMerger.toTimeString(timePmList);
            String timePmStringLast = TimeIntervalMerger.toTimeString(timePmListLast);
            peakResultResponseVO.setThisWeekPmPeakTimeSpan(timePmString);

            //本周晚高峰集中时段持续时长45分钟
            String[] timePmSpans = timePmString.split("~");
            String[] timePmSpansLast = timePmStringLast.split("~");
            Long thisWeekPmPeakDuration = 0L;
            if (ObjectUtil.isNotEmpty(timePmString)) {
                thisWeekPmPeakDuration = getTimeSum(timePmSpans[0], timePmSpans[1]);
            }
            Long thisWeekPmPeakDurationLast = 0L;
            if (ObjectUtil.isNotEmpty(timePmStringLast)) {
                thisWeekPmPeakDurationLast = getTimeSum(timePmSpansLast[0], timePmSpansLast[1]);
            }

            peakResultResponseVO.setThisWeekPmPeakDuration(thisWeekPmPeakDuration + "分钟");

            //本周晚高峰时段开始时间上周比较情况提前【延后】20分钟
            Long thisWeekPmPeakStartTimeSituation = getTimeSum(timePmSpansLast[0], timePmSpans[0]);
            if (thisWeekPmPeakStartTimeSituation > 0) {
                peakResultResponseVO.setThisWeekPmPeakStartTimeSituation("延后" + thisWeekPmPeakStartTimeSituation + "分钟");
            } else {
                peakResultResponseVO.setThisWeekPmPeakStartTimeSituation("提前" + Math.abs(thisWeekPmPeakStartTimeSituation) + "分钟");
            }

            //本周晚高峰时段结束时间上周比较情况提前【延后】20分钟
            Long thisWeekPmPeakEndTimeSituation = getTimeSum(timePmSpansLast[0], timePmSpans[0]);
            if (thisWeekPmPeakEndTimeSituation > 0) {
                peakResultResponseVO.setThisWeekPmPeakEndTimeSituation("延后" + thisWeekPmPeakEndTimeSituation + "分钟");
            } else {
                peakResultResponseVO.setThisWeekPmPeakEndTimeSituation("提前" + Math.abs(thisWeekPmPeakEndTimeSituation) + "分钟");
            }

            //本周晚高峰持续时长上周比较情况提前【延后】20分钟
            Long thisWeekPmPeakDurationSituation = thisWeekPmPeakDuration - thisWeekPmPeakDurationLast;
            if (thisWeekPmPeakDurationSituation > 0) {
                peakResultResponseVO.setThisWeekPmPeakDurationSituation("延后" + thisWeekPmPeakDurationSituation + "分钟");
            } else {
                peakResultResponseVO.setThisWeekPmPeakDurationSituation("提前" + Math.abs(thisWeekPmPeakDurationSituation) + "分钟");
            }

            //峰期交通流参数对比分析
            List<CrossRunStatePeakDetailAnalysisDataVO> analysisDataVOList = new ArrayList<>();
            Map<String, List<AnalysisReportCrossPeakDetail>> peakMap = peakDetails.stream().collect(Collectors.groupingBy(AnalysisReportCrossPeakDetail::getPeakType));
            Map<String, List<AnalysisReportCrossPeakDetail>> peakMapLast = peakDetailsLast.stream().collect(Collectors.groupingBy(AnalysisReportCrossPeakDetail::getPeakType));
            for (String peakType : peakMap.keySet()) {
                CrossRunStatePeakDetailAnalysisDataVO analysisDataVO = new CrossRunStatePeakDetailAnalysisDataVO();
                if ("1".equals(peakType)) {
                    analysisDataVO.setPeakName("早高峰");
                } else if ("2".equals(peakType)) {
                    analysisDataVO.setPeakName("晚高峰");
                } else {
                    continue;
                }
                List<AnalysisReportCrossPeakDetail> detailList = peakMap.get(peakType);
                List<AnalysisReportCrossPeakDetail> detailListLast = ObjectUtil.isEmpty(peakMapLast.get(peakType)) ? new ArrayList<>() : peakMapLast.get(peakType);
                //本周交通指数3.4
                double thisWeekTrafficIndex = detailList.stream().mapToDouble(AnalysisReportCrossPeakDetail::getPeakTrafficIndex).average().orElse(0.0);
                analysisDataVO.setThisWeekTrafficIndex(Integer.valueOf(String.valueOf(Math.round(thisWeekTrafficIndex))));
                //上周交通指数3.4
                double lastWeekTrafficIndex = detailListLast.stream().mapToDouble(AnalysisReportCrossPeakDetail::getPeakTrafficIndex).average().orElse(0.0);
                analysisDataVO.setLastWeekTrafficIndex(Integer.valueOf(String.valueOf(Math.round(lastWeekTrafficIndex))));

                //本周通行能力15900
                double thisWeekWorkCapacity = detailList.stream().mapToDouble(AnalysisReportCrossPeakDetail::getPeakCapacity).average().orElse(0.0);
                analysisDataVO.setThisWeekWorkCapacity(Integer.valueOf(String.valueOf(Math.round(thisWeekWorkCapacity))));
                //上周通行能力16000
                double lastWeekCapacity = detailListLast.stream().mapToDouble(AnalysisReportCrossPeakDetail::getPeakCapacity).average().orElse(0.0);
                analysisDataVO.setLastWeekCapacity(Integer.valueOf(String.valueOf(Math.round(lastWeekCapacity))));

                //本周平均延误40
                double thisWeekWorkDelayTime = detailList.stream().mapToDouble(AnalysisReportCrossPeakDetail::getPeakAvgDeayTime).average().orElse(0.0);
                analysisDataVO.setThisWeekWorkDelayTime(Integer.valueOf(String.valueOf(Math.round(thisWeekWorkDelayTime))));
                //上周平均延误40
                double lastWeekDelayTime = detailListLast.stream().mapToDouble(AnalysisReportCrossPeakDetail::getPeakAvgDeayTime).average().orElse(0.0);
                analysisDataVO.setLastWeekDelayTime(Integer.valueOf(String.valueOf(Math.round(lastWeekDelayTime))));

                //本周最大排队240
                double thisWeekMaxQueueLength = detailList.stream().mapToDouble(AnalysisReportCrossPeakDetail::getPeakMaxQueueLength).average().orElse(0.0);
                analysisDataVO.setThisWeekMaxQueueLength(Integer.valueOf(String.valueOf(Math.round(thisWeekMaxQueueLength))));
                //上周最大排队240
                double lastWeekMaxQueueLength = detailListLast.stream().mapToDouble(AnalysisReportCrossPeakDetail::getPeakMaxQueueLength).average().orElse(0.0);
                analysisDataVO.setLastWeekMaxQueueLength(Integer.valueOf(String.valueOf(Math.round(lastWeekMaxQueueLength))));

                //本周停车次数4
                double thisWeekStopTimes = detailList.stream().mapToDouble(AnalysisReportCrossPeakDetail::getPeakAvgStopTimes).average().orElse(0.0);
                analysisDataVO.setThisWeekStopTimes(Integer.valueOf(String.valueOf(Math.round(thisWeekStopTimes))));
                //上周停车次数3.5
                double lastWeekStopTimes = detailListLast.stream().mapToDouble(AnalysisReportCrossPeakDetail::getPeakAvgStopTimes).average().orElse(0.0);
                analysisDataVO.setLastWeekStopTimes(Integer.valueOf(String.valueOf(Math.round(lastWeekStopTimes))));

                analysisDataVOList.add(analysisDataVO);
            }
            peakResultResponseVO.setDataList(analysisDataVOList);

            //高峰期时段分析
            List<CrossRunStatePeakTimeSpanAnalysisDataVO> peakTimeSpanAnalysisDataVOList = new ArrayList<>();
            Map<Integer, List<AnalysisReportCrossPeakDetail>> weekMap = peakDetails.stream().collect(Collectors.groupingBy(AnalysisReportCrossPeakDetail::getWeekDay));
            Map<Integer, List<AnalysisReportCrossPeakDetail>> weekMapLast = peakDetailsLast.stream().collect(Collectors.groupingBy(AnalysisReportCrossPeakDetail::getWeekDay));
            for (Integer weekDay : weekMap.keySet()) {
                CrossRunStatePeakTimeSpanAnalysisDataVO analysisDataVO = new CrossRunStatePeakTimeSpanAnalysisDataVO();
                analysisDataVO.setWeekName(WeekEnum.getDesc(weekDay));
                //本周早高峰时段"7:00~8:00"
                List<String> timeWeekAmList = new ArrayList<>();
                weekMap.get(weekDay).stream().filter(x -> "1".equals(x.getPeakType())).forEach(x -> {
                    String timeWeekPmString = getTimeString(x);
                    timeWeekAmList.add(timeWeekPmString);
                });
                String thisWeekAmPeakTimeSpan = TimeIntervalMerger.toTimeString(timeWeekAmList);
                analysisDataVO.setThisWeekAmPeakTimeSpan(thisWeekAmPeakTimeSpan);
                //上周早高峰时段"7:00~8:00"
                List<String> timeWeekAmListLast = new ArrayList<>();
                List<AnalysisReportCrossPeakDetail> crossPeakDetailListLast = ObjectUtil.isEmpty(weekMapLast.get(weekDay)) ? new ArrayList<>() : weekMapLast.get(weekDay);
                crossPeakDetailListLast.stream().filter(x -> "1".equals(x.getPeakType())).forEach(x -> {
                    String timeWeekPmString = getTimeString(x);
                    timeWeekAmListLast.add(timeWeekPmString);
                });
                String lastWeekAmPeakTimeSpan = TimeIntervalMerger.toTimeString(timeWeekAmListLast);
                analysisDataVO.setLastWeekAmPeakTimeSpan(lastWeekAmPeakTimeSpan);

                //本周早高峰持续时长（min）"30"
                String[] times = thisWeekAmPeakTimeSpan.split("~");
                Long thisWeekAmPeakDurationWeek = 0L;
                if (ObjectUtil.isNotEmpty(thisWeekAmPeakTimeSpan)) {
                    thisWeekAmPeakDurationWeek = getTimeSum(times[0], times[1]);
                }

                analysisDataVO.setThisWeekAmPeakDuration(String.valueOf(thisWeekAmPeakDurationWeek));
                //上周早高峰持续时长（min）"30"
                String[] timesLast = lastWeekAmPeakTimeSpan.split("~");
                Long lastWeekAmPeakDuration = 0L;
                if (ObjectUtil.isNotEmpty(lastWeekAmPeakTimeSpan)) {
                    lastWeekAmPeakDuration = getTimeSum(timesLast[0], timesLast[1]);
                }
                analysisDataVO.setLastWeekAmPeakDuration(String.valueOf(lastWeekAmPeakDuration));

                //本周晚高峰时段"7:00~8:00"
                List<String> timeWeekPmList = new ArrayList<>();
                weekMap.get(weekDay).stream().filter(x -> "2".equals(x.getPeakType())).forEach(x -> {
                    String timeWeekPmString = getTimeString(x);
                    timeWeekPmList.add(timeWeekPmString);
                });
                String thisWeekPmPeakTimeSpan = TimeIntervalMerger.toTimeString(timeWeekPmList);
                analysisDataVO.setThisWeekPmPeakTimeSpan(thisWeekPmPeakTimeSpan);

                //上周晚高峰时段"7:00~8:00"
                List<String> timeWeekPmListLast = new ArrayList<>();
                crossPeakDetailListLast.stream().filter(x -> "2".equals(x.getPeakType())).forEach(x -> {
                    String timeWeekPmString = getTimeString(x);
                    timeWeekPmListLast.add(timeWeekPmString);
                });
                String lastWeekPmPeakTimeSpan = TimeIntervalMerger.toTimeString(timeWeekPmListLast);
                analysisDataVO.setLastWeekPmPeakTimeSpan(lastWeekPmPeakTimeSpan);

                //本周晚高峰持续时长（min） "30"
                String[] pmTimes = thisWeekAmPeakTimeSpan.split("~");
                Long thisWeekPmPeakDurationWeek = 0L;
                if (ObjectUtil.isNotEmpty(thisWeekAmPeakTimeSpan)) {
                    thisWeekPmPeakDurationWeek = getTimeSum(pmTimes[0], pmTimes[1]);
                }

                analysisDataVO.setThisWeekPmPeakDuration(String.valueOf(thisWeekPmPeakDurationWeek));
                //上周晚高峰持续时长（min） "30"
                String[] pmTimeslast = lastWeekPmPeakTimeSpan.split("~");
                Long lastWeekPmPeakDuration = 0L;
                if (ObjectUtil.isNotEmpty(lastWeekPmPeakTimeSpan)) {
                    lastWeekPmPeakDuration = getTimeSum(pmTimeslast[0], pmTimeslast[1]);
                }
                analysisDataVO.setLastWeekPmPeakDuration(String.valueOf(lastWeekPmPeakDuration));

                peakTimeSpanAnalysisDataVOList.add(analysisDataVO);
            }
            peakResultResponseVO.setPeakList(peakTimeSpanAnalysisDataVOList);

            crossRunStatePeakResultResponseVOList.add(peakResultResponseVO);
        }

        return crossRunStatePeakResultResponseVOList;
    }

    @Override
    public CrossOptimizeResultResponseVO getTotalityData(Integer year, Integer week, String crossIds) {
        List<String> crossIdList = null;
        Integer yearWeek = Integer.valueOf("" + year + week);
        if (ObjectUtil.isNotEmpty(crossIds)) {
            crossIdList = Arrays.stream(crossIds.split(","))
                    .map(String::trim) // 去除可能的空格
                    .filter(s -> !s.isEmpty()) // 过滤掉空字符串
                    .collect(Collectors.toList());
        }
        List<AnalysisReportCrossOptimizeDetailVO> optimizeDetails = crossRidLaneMapper.getTotalityData(yearWeek, crossIdList);
        if (ObjectUtil.isEmpty(optimizeDetails)) {
            return null;
        }

        CrossOptimizeResultResponseVO resultResponseVO = new CrossOptimizeResultResponseVO();

        Map<Integer, Integer> optimizeCountMap = optimizeDetails.stream().collect(Collectors.groupingBy(
                AnalysisReportCrossOptimizeDetailVO::getStragetyId,
                Collectors.summingInt(AnalysisReportCrossOptimizeDetailVO::getOptimizeCount)
        ));
        //本周优化次数 "300"
        int weekOptimizeCount = optimizeCountMap.values().stream().mapToInt(x -> x).sum();
        resultResponseVO.setWeekOptimizeCount(String.valueOf(weekOptimizeCount));
        //本周优化时长 "98"
        int weekOptimizeDuration = optimizeDetails.stream().mapToInt(AnalysisReportCrossOptimizeDetailVO::getOptimizeDuration).sum();
        resultResponseVO.setWeekOptimizeDuration(String.valueOf(weekOptimizeDuration));
        //本周溢出次数"98"
        Integer optimizeOverflowCount = optimizeCountMap.get(StrategyEnum.OVERFLOW.getCode());
        resultResponseVO.setWeekOptimizeOverflowCount(String.valueOf(ObjectUtil.isNull(optimizeOverflowCount) ? 0 : optimizeOverflowCount));
        //本周拥堵次数 "98"
        Integer optimizeCongestCount = optimizeCountMap.get(StrategyEnum.CONGESTION.getCode());
        resultResponseVO.setWeekOptimizeCongestCount(String.valueOf(ObjectUtil.isNull(optimizeCongestCount) ? 0 : optimizeCongestCount));
        //本周空放优化次数 "98"
        Integer weekOptimizeEmptyCount = optimizeCountMap.get(StrategyEnum.GREEN_LIGHT_IDLE.getCode());
        resultResponseVO.setWeekOptimizeEmptyCount(String.valueOf(ObjectUtil.isNull(weekOptimizeEmptyCount) ? 0 : weekOptimizeEmptyCount));
        //本周失衡优化次数 "98"
        Integer weekOptimizeUnbalanceCount = optimizeCountMap.get(StrategyEnum.IMBALANCE.getCode());
        resultResponseVO.setWeekOptimizeUnbalanceCount(String.valueOf(ObjectUtil.isNull(weekOptimizeUnbalanceCount) ? 0 : weekOptimizeUnbalanceCount));

        //本周通行能力同比情况 "提升10%"
        int weekCapacity = optimizeDetails.stream().mapToInt(AnalysisReportCrossOptimizeDetailVO::getCapacity).max().orElse(0);
        int weekCapacityLast = optimizeDetails.stream().mapToInt(AnalysisReportCrossOptimizeDetailVO::getLastWeekCapacity).max().orElse(0);
        int weekCapacitySituation = (weekCapacity - weekCapacityLast) / weekCapacityLast * 100;
        if (weekCapacitySituation > 0) {
            resultResponseVO.setWeekCapacitySituation("提升" + weekCapacitySituation + "%");
        } else {
            resultResponseVO.setWeekCapacitySituation("降低" + Math.abs(weekCapacitySituation) + "%");
        }
        //本周通停车次数同比情况 "减少10%"
        double weekStopTimes = optimizeDetails.stream().mapToDouble(AnalysisReportCrossOptimizeDetailVO::getStopTimes).max().orElse(0.0);
        double weekStopTimesLast = optimizeDetails.stream().mapToDouble(AnalysisReportCrossOptimizeDetailVO::getLastWeekStopTimes).max().orElse(0.0);
        long weekStopTimesSituation = Math.round((weekStopTimes - weekStopTimesLast) / weekStopTimesLast * 100);
        if (weekCapacitySituation > 0) {
            resultResponseVO.setWeekStopTimesSituation("增加" + weekStopTimesSituation + "%");
        } else {
            resultResponseVO.setWeekStopTimesSituation("减少" + Math.abs(weekStopTimesSituation) + "%");
        }
        //本周通延误时间同比情况 "增加10%"
        double weekDelayTime = optimizeDetails.stream().mapToDouble(AnalysisReportCrossOptimizeDetailVO::getDelayTime).average().orElse(0.0);
        double weekDelayTimeLast = optimizeDetails.stream().mapToDouble(AnalysisReportCrossOptimizeDetailVO::getLastWeekDelayTime).average().orElse(0.0);
        long weekDelayTimeSituation = Math.round((weekDelayTime - weekDelayTimeLast) / weekDelayTimeLast * 100);
        if (weekDelayTimeSituation > 0) {
            resultResponseVO.setWeekDelayTimeSituation("增加" + weekDelayTimeSituation + "%");
        } else {
            resultResponseVO.setWeekDelayTimeSituation("减少" + Math.abs(weekDelayTimeSituation) + "%");
        }
        //本周通最大排队同比情况 "降低10%"
        double weekMaxQueueLength = optimizeDetails.stream().mapToDouble(AnalysisReportCrossOptimizeDetailVO::getMaxQueueLength).max().orElse(0.0);
        double weekMaxQueueLengthLast = optimizeDetails.stream().mapToDouble(AnalysisReportCrossOptimizeDetailVO::getLastWeekMaxQueueLength).max().orElse(0.0);
        long weekMaxQueueLengthSituation = Math.round((weekMaxQueueLength - weekMaxQueueLengthLast) / weekMaxQueueLengthLast * 100);
        if (weekMaxQueueLengthSituation > 0) {
            resultResponseVO.setWeekMaxQueueLengthSituation("增加" + weekMaxQueueLengthSituation + "%");
        } else {
            resultResponseVO.setWeekMaxQueueLengthSituation("减少" + Math.abs(weekMaxQueueLengthSituation) + "%");
        }
        //本周总体情况 "明显提升"
        long weekTotality = weekCapacitySituation - weekDelayTimeSituation;
        if (weekTotality > 0) {
            if (weekTotality > 5) {
                resultResponseVO.setWeekTotalitySituation("明显提升");
            } else {
                resultResponseVO.setWeekTotalitySituation("略有提升");
            }
        } else {
            if (Math.abs(weekTotality) > 5) {
                resultResponseVO.setWeekTotalitySituation("明显下降");
            } else {
                resultResponseVO.setWeekTotalitySituation("略有下降");
            }
        }
        List<String> timeList = new ArrayList<>();
        timeList.add("本周");
        timeList.add("上周");
        resultResponseVO.setTimeList(timeList);
        List<CrossOptimizeAnalysisDataVO> crossOptimizeAnalysisDataVOList = new ArrayList<>();
        CrossOptimizeAnalysisDataVO crossOptimizeAnalysisDataVO = new CrossOptimizeAnalysisDataVO();
        CrossOptimizeAnalysisDataVO crossOptimizeAnalysisDataVOLast = new CrossOptimizeAnalysisDataVO();

        crossOptimizeAnalysisDataVO.setCapacity(weekCapacity);
        crossOptimizeAnalysisDataVO.setDelayTime(Math.round(weekDelayTime * 100) / 100.0);
        crossOptimizeAnalysisDataVO.setMaxQueueLength(Math.round(weekMaxQueueLength * 100) / 100.0);
        crossOptimizeAnalysisDataVO.setStopTimes(Math.round(weekStopTimes * 100) / 100.0);
        crossOptimizeAnalysisDataVOLast.setCapacity(weekCapacityLast);
        crossOptimizeAnalysisDataVOLast.setDelayTime(Math.round(weekDelayTimeLast * 100) / 100.0);
        crossOptimizeAnalysisDataVOLast.setMaxQueueLength(Math.round(weekMaxQueueLengthLast * 100) / 100.0);
        crossOptimizeAnalysisDataVOLast.setStopTimes(Math.round(weekStopTimesLast * 100) / 100.0);

        crossOptimizeAnalysisDataVOList.add(crossOptimizeAnalysisDataVO);
        crossOptimizeAnalysisDataVOList.add(crossOptimizeAnalysisDataVOLast);
        resultResponseVO.setDataList(crossOptimizeAnalysisDataVOList);

        return resultResponseVO;
    }

    @Override
    public List<ImportCrossAnalysisResponseVO> getProblemDetail(Integer year, Integer week, String crossIds) {
        List<String> crossIdList = null;
        Integer yearWeek = Integer.valueOf("" + year + week);
        if (ObjectUtil.isNotEmpty(crossIds)) {
            crossIdList = Arrays.stream(crossIds.split(","))
                    .map(String::trim) // 去除可能的空格
                    .filter(s -> !s.isEmpty()) // 过滤掉空字符串
                    .collect(Collectors.toList());
        }
        List<AnalysisReportCrossOptimizeDetailVO> optimizeDetailList = crossRidLaneMapper.getTotalityData(yearWeek, crossIdList);
        if (ObjectUtil.isEmpty(optimizeDetailList)) {
            return null;
        }
        Map<String, List<AnalysisReportCrossOptimizeDetailVO>> crossIdMap = optimizeDetailList.stream().collect(Collectors.groupingBy(AnalysisReportCrossOptimizeDetailVO::getCrossId));
        List<ImportCrossAnalysisResponseVO> responseVOS = new ArrayList<>();
        for (String crossId : crossIdMap.keySet()) {
            List<AnalysisReportCrossOptimizeDetailVO> optimizeDetailVOS = crossIdMap.get(crossId);
            Map<Integer, Integer> optimizeCountMap = optimizeDetailVOS.stream().collect(Collectors.groupingBy(
                    AnalysisReportCrossOptimizeDetailVO::getStragetyId,
                    Collectors.summingInt(AnalysisReportCrossOptimizeDetailVO::getOptimizeCount)
            ));
            /*非拥堵问题超过10次以上，或溢出问题超过5次以上，或空放问题超过20次以上，或失衡问题超过15次以上的路口直接结束*/
            if ((ObjectUtil.isNotEmpty(optimizeCountMap.get(StrategyEnum.GREEN_LIGHT_IDLE.getCode())) && optimizeCountMap.get(StrategyEnum.GREEN_LIGHT_IDLE.getCode()) < 20) || (ObjectUtil.isNotEmpty(optimizeCountMap.get(StrategyEnum.IMBALANCE.getCode())) && optimizeCountMap.get(StrategyEnum.IMBALANCE.getCode()) < 15) || (ObjectUtil.isNotEmpty(optimizeCountMap.get(StrategyEnum.OVERFLOW.getCode())) && optimizeCountMap.get(StrategyEnum.OVERFLOW.getCode()) < 5) || (ObjectUtil.isNotEmpty(optimizeCountMap.get(StrategyEnum.CONGESTION.getCode())) && optimizeCountMap.get(StrategyEnum.CONGESTION.getCode()) < 10)) {
                continue;
            }
            ImportCrossAnalysisResponseVO analysisResponseVO = new ImportCrossAnalysisResponseVO();
            BaseCrossInfoPO baseCrossInfoPO = baseCrossInfoMapper.selectById(crossId);
            //路口名称 "经十路（舜耕路-山大路）"
            analysisResponseVO.setCrossName(baseCrossInfoPO.getName());

            //本周优化集中时段分布情况"7:00~8:00,12:00~13:30,17:30~18:40"
            List<String> timeList = new ArrayList<>();
            optimizeDetailVOS.forEach(x -> {
                String timeString = getTimeString(x);
                timeList.add(timeString);
            });
            String optimizeTimeString = TimeIntervalMerger.timeString(timeList);
            analysisResponseVO.setOptimizeSpan(optimizeTimeString);

            //本周溢出优化次数 "10次"
            analysisResponseVO.setOverFlowOptimizeCount((ObjectUtil.isNotEmpty(optimizeCountMap.get(StrategyEnum.OVERFLOW.getCode())) ? optimizeCountMap.get(StrategyEnum.OVERFLOW.getCode()) : 0) + "次");
            //本周溢出主要发生方向 "北出口、南出口"
            List<String> overFlowDirs = new ArrayList<>();
            optimizeDetailVOS.stream().filter(x -> x.getStragetyId() == StrategyEnum.OVERFLOW.getCode()).forEach(x -> {
                overFlowDirs.add(x.getDirs());
            });
            analysisResponseVO.setOverFlowDirs(getDirs(overFlowDirs));

            //本周拥堵优化次数 "10次"
            analysisResponseVO.setCongestOptimizeCount((ObjectUtil.isNotEmpty(optimizeCountMap.get(StrategyEnum.CONGESTION.getCode())) ? optimizeCountMap.get(StrategyEnum.CONGESTION.getCode()) : 0) + "次");
            //本周拥堵主要发生方向 "北出口、南出口"
            List<String> congestDirs = new ArrayList<>();
            optimizeDetailVOS.stream().filter(x -> x.getStragetyId() == StrategyEnum.CONGESTION.getCode()).forEach(x -> {
                congestDirs.add(x.getDirs());
            });
            analysisResponseVO.setCongestDirs(getDirs(congestDirs));

            //本周空放优化次数 "10次"
            analysisResponseVO.setEmptyPassOptimizeCount((ObjectUtil.isNotEmpty(optimizeCountMap.get(StrategyEnum.GREEN_LIGHT_IDLE.getCode())) ? optimizeCountMap.get(StrategyEnum.GREEN_LIGHT_IDLE.getCode()) : 0) + "次");
            //本周空放主要发生方向 "北出口、南出口"
            List<String> emptyPassDirs = new ArrayList<>();
            optimizeDetailVOS.stream().filter(x -> x.getStragetyId() == StrategyEnum.GREEN_LIGHT_IDLE.getCode()).forEach(x -> {
                emptyPassDirs.add(x.getDirs());
            });
            analysisResponseVO.setEmptyPassDirs(getDirs(emptyPassDirs));

            //本周失衡优化次数 "10次"
            analysisResponseVO.setUnbalanceOptimizeCount((ObjectUtil.isNotEmpty(optimizeCountMap.get(StrategyEnum.IMBALANCE.getCode())) ? optimizeCountMap.get(StrategyEnum.IMBALANCE.getCode()) : 0) + "次");
            //本周失衡主要发生方向 "北出口、南出口"
            List<String> unbalanceDirs = new ArrayList<>();
            optimizeDetailVOS.stream().filter(x -> x.getStragetyId() == StrategyEnum.IMBALANCE.getCode()).forEach(x -> {
                unbalanceDirs.add(x.getDirs());
            });
            analysisResponseVO.setUnbalanceDirs(getDirs(unbalanceDirs));
            //================================================================================================//
            //本周平均通行能力 "7800辆/小时"
            double avgCapacity = optimizeDetailVOS.stream().mapToInt(AnalysisReportCrossOptimizeDetailVO::getCapacity).average().orElse(0.0);
            double avgCapacityLast = optimizeDetailVOS.stream().mapToInt(AnalysisReportCrossOptimizeDetailVO::getLastWeekCapacity).average().orElse(0.0);
            analysisResponseVO.setAvgCapacity(Math.round(avgCapacity) + "辆/小时");
            //平均通行能力与上周相比情况 "提升"
            double avgCapacityCompareSituation = 0;
            if (avgCapacityLast != 0) {
                avgCapacityCompareSituation = Math.round((avgCapacity - avgCapacityLast) / avgCapacityLast * 10000) / 100.0;
            }
            if (avgCapacityCompareSituation > 0) {
                analysisResponseVO.setAvgCapacityCompareSituation("提升" + avgCapacityCompareSituation + "%");
            } else {
                analysisResponseVO.setAvgCapacityCompareSituation("降低" + Math.abs(avgCapacityCompareSituation) + "%");
            }
            //================================================================================================//
            //本周延误时间"22"
            double delayTime = optimizeDetailVOS.stream().mapToDouble(AnalysisReportCrossOptimizeDetailVO::getDelayTime).average().orElse(0.0);
            double delayTimeLast = optimizeDetailVOS.stream().mapToDouble(AnalysisReportCrossOptimizeDetailVO::getLastWeekDelayTime).average().orElse(0.0);
            analysisResponseVO.setDelayTime(String.valueOf(Math.round(delayTime)));
            //延误时间与上周相比情况 "增加【减少】10%"
            double delayTimeCompare = 0;
            if (delayTimeLast != 0) {
                delayTimeCompare = Math.round((delayTime - delayTimeLast) / delayTimeLast * 10000) / 100.0;
            }
            if (delayTimeCompare > 0) {
                analysisResponseVO.setDelayTimeCompare("增加" + delayTimeCompare + "%");
            } else {
                analysisResponseVO.setDelayTimeCompare("减少" + Math.abs(delayTimeCompare) + "%");
            }
            //================================================================================================//
            //本周停车次数 "22"
            double avgStopTimes = optimizeDetailVOS.stream().mapToDouble(AnalysisReportCrossOptimizeDetailVO::getStopTimes).average().orElse(0.0);
            double avgStopTimesLast = optimizeDetailVOS.stream().mapToDouble(AnalysisReportCrossOptimizeDetailVO::getLastWeekStopTimes).average().orElse(0.0);
            analysisResponseVO.setAvgStopTimes(String.valueOf(Math.round(avgStopTimes)));
            //本周停车次数与上周相比情况 "增加【减少】10%"
            double avgStopTimesCompare = 0;
            if (avgStopTimesLast != 0) {
                avgStopTimesCompare = Math.round((avgStopTimes - avgStopTimesLast) / avgStopTimesLast * 10000) / 100.0;
            }
            if (avgStopTimesCompare > 0) {
                analysisResponseVO.setAvgStopTimesCompare("增加" + avgStopTimesCompare + "%");
            } else {
                analysisResponseVO.setAvgStopTimesCompare("减少" + Math.abs(avgStopTimesCompare) + "%");
            }
            //================================================================================================//
            //本周最大排队长度 "203"
            double maxQueueLength = optimizeDetailVOS.stream().mapToDouble(AnalysisReportCrossOptimizeDetailVO::getMaxQueueLength).max().orElse(0.0);
            double maxQueueLengthLast = optimizeDetailVOS.stream().mapToDouble(AnalysisReportCrossOptimizeDetailVO::getLastWeekMaxQueueLength).max().orElse(0.0);
            analysisResponseVO.setMaxQueueLength(String.valueOf(Math.round(maxQueueLength)));
            //本周最大排队长度与上周相比情况 "提升【降低】10%"
            double maxQueueLengthCompare = 0;
            if (maxQueueLengthLast != 0) {
                maxQueueLengthCompare = Math.round((maxQueueLength - maxQueueLengthLast) / maxQueueLengthLast * 10000) / 100.0;
            }
            if (maxQueueLengthCompare > 0) {
                analysisResponseVO.setMaxQueueLengthCompare("提升" + maxQueueLengthCompare + "%");
            } else {
                analysisResponseVO.setMaxQueueLengthCompare("降低" + Math.abs(maxQueueLengthCompare) + "%");
            }
            //================================================================================================//
            //本周总体效果情况 "明显提升"
            if (avgCapacityCompareSituation > 0) {
                analysisResponseVO.setWeekTotalitySituation("明显提升");
            } else if (avgCapacityCompareSituation == 0) {
                analysisResponseVO.setWeekTotalitySituation("持平");
            } else {
                analysisResponseVO.setWeekTotalitySituation("略有下降");
            }
            List<ImportCrossReportAnalysisDataVO> reportAnalysisDataVOS = new ArrayList<>();
            optimizeDetailVOS.forEach(x -> {
                ImportCrossReportAnalysisDataVO reportAnalysisDataVO = new ImportCrossReportAnalysisDataVO();
                reportAnalysisDataVO.setWeekName(WeekEnum.getDesc(x.getWeekDay()));
                reportAnalysisDataVO.setOptimizeTimeSpan(getTimeString(x));
                reportAnalysisDataVO.setThisWeekCountRadio((ObjectUtil.isNotEmpty(x.getOptimizeCount()) ? x.getOptimizeCount() : 0) + "/" + (ObjectUtil.isNotEmpty(x.getProblemCount()) ? x.getProblemCount() : 0));
                reportAnalysisDataVO.setLastWeekCountRadio((ObjectUtil.isNotEmpty(x.getLastWeekOptimizeCount()) ? x.getLastWeekOptimizeCount() : 0) + "/" + (ObjectUtil.isNotEmpty(x.getLastWeekProblemCount()) ? x.getLastWeekProblemCount() : 0));
                reportAnalysisDataVO.setThisWeekCapacity(ObjectUtil.isNotEmpty(x.getCapacity()) ? x.getCapacity() : 0);
                reportAnalysisDataVO.setLastWeekCapacity(ObjectUtil.isNotEmpty(x.getLastWeekCapacity()) ? x.getLastWeekCapacity() : 0);
                reportAnalysisDataVO.setThisWeekStopTimes(ObjectUtil.isNotEmpty(x.getStopTimes()) ? x.getStopTimes() : 0);
                reportAnalysisDataVO.setLastWeekStopTimes(ObjectUtil.isNotEmpty(x.getLastWeekStopTimes()) ? x.getLastWeekStopTimes() : 0);
                reportAnalysisDataVO.setThisWeekDelayTime(ObjectUtil.isNotEmpty(x.getDelayTime()) ? x.getDelayTime() : 0);
                reportAnalysisDataVO.setLastWeekDelayTime(ObjectUtil.isNotEmpty(x.getLastWeekDelayTime()) ? x.getLastWeekDelayTime() : 0);
                reportAnalysisDataVO.setThisWeekMaxQueueLength(ObjectUtil.isNotEmpty(x.getMaxQueueLength()) ? Double.valueOf(x.getMaxQueueLength()) : 0);
                reportAnalysisDataVO.setLastWeekMaxQueueLength(ObjectUtil.isNotEmpty(x.getLastWeekMaxQueueLength()) ? Double.valueOf(x.getLastWeekMaxQueueLength()) : 0);
                reportAnalysisDataVOS.add(reportAnalysisDataVO);
            });
            analysisResponseVO.setDataList(reportAnalysisDataVOS);

            responseVOS.add(analysisResponseVO);
        }
        return responseVOS;
    }

    private String getDirs(List<String> dirs) {
        if (ObjectUtil.isEmpty(dirs)) {
            return "";
        }
        // 1. 解析
        List<String> dirAllList = new ArrayList<>();
        for (String dir : dirs) {
            if (ObjectUtil.isEmpty(dir)) {
                continue;
            }
            String[] s = dir.replace("[", "").replace("]", "").replaceAll(" ", "").split(",|，");
            List<String> dirList = Arrays.asList(s);
            dirAllList.addAll(dirList);
        }

        // 2. 统计每个元素的出现次数
        Map<String, Long> frequencyMap = dirAllList.stream()
                .collect(Collectors.groupingBy(e -> e, Collectors.counting()));

        // 3. 按照频率降序排序，并取出前两个或一个
        List<Map.Entry<String, Long>> sortedEntries = frequencyMap.entrySet().stream()
                .sorted((e1, e2) -> e2.getValue().compareTo(e1.getValue())) // 按值降序排序
                .limit(2) // 取前两个
                .collect(Collectors.toList());
        String resultDir = "";
        for (Map.Entry<String, Long> sortedEntry : sortedEntries) {
            if (ObjectUtil.isNotEmpty(resultDir)) {
                resultDir = resultDir + "、" + sortedEntry.getKey();
            } else {
                resultDir = sortedEntry.getKey();
            }
        }
        return resultDir;
    }

    private Long getTimeSum(String timeSpan, String timeSpan1) {
        // 定义时间格式
        SimpleDateFormat sdf = new SimpleDateFormat("HH:mm");
        Date startTime = null;
        Date endTime = null;
        try {
            startTime = sdf.parse(timeSpan);
            endTime = sdf.parse(timeSpan1);
        } catch (Exception e) {
            return 0L;
        }
        // 定义开始时间和结束时间


        // 计算时间差（单位：毫秒）
        long differenceInMillis = endTime.getTime() - startTime.getTime();

        // 转换为分钟
        long minutesDifference = differenceInMillis / (1000 * 60);
        return minutesDifference;
    }

    private String getLaneDir(Integer dir) {
        switch (dir) {
            case 1:
                return "南北走向";
            case 2:
                return "东北西南走向";
            case 3:
                return "东西走向";
            case 4:
                return "东南西北走向";
            case 5:
                return "南北走向";
            case 6:
                return "东北西南走向";
            case 7:
                return "东西走向";
            case 8:
                return "东南西北走向";
            default:
                return "东西走向";
        }
    }

    private String getTimeString(AnalysisReportCrossPeakDetail peakDetail) {
        String start = format.format(peakDetail.getPeakStartTime());
        String end = format.format(peakDetail.getPeakEndTime());
        return start + "~" + end;
    }

    private String getTimeString(AnalysisReportCrossOptimizeDetailVO peakDetail) {
        String start = format.format(peakDetail.getOptimizeStartTime());
        String end = format.format(peakDetail.getOptimizeEndTime());
        return start + "~" + end;
    }

    private String getLocation(String location) {
        // 提取经纬度
        try {
            // 去掉 "POINT(" 和 ")"
            String content = location.substring(6, location.length() - 1);

            // 按空格分割
            String[] parts = content.split("\\s+");

            if (parts.length == 2) {
                String longitude = parts[0]; // 经度
                String latitude = parts[1];  // 纬度

                return longitude + "," + latitude;
            } else {
                log.error("未找到匹配的 POINT 格式");
            }
        } catch (Exception e) {
            log.error("解析失败: " + e.getMessage());
        }
        return "";
    }
}